@@ -2,6 +2,7 @@ import copy
 import functools
 import numbers
 import operator
+import warnings
 
 from django.conf import settings
 from django.utils.encoding import smart_text
@@ -33,6 +34,12 @@ class Facet(object):
         self.description = description
         self.login_required = kwargs.pop('login_required', False)
 
+        if self.login_required:
+            warnings.warn(
+                    "The 'login_required' facet attribute will be deprecated in Seeker 8.0. Please add the facet field to 'login_required_columns' instead.",
+                    DeprecationWarning
+                )
+
         default_related_column_name = self.field.split('.')[0]
         related_column_name = kwargs.get('related_column_name')
         self.related_column_name = related_column_name if isinstance(related_column_name, str) else default_related_column_name
