@@ -10,7 +10,6 @@ logger = logging.getLogger(__name__)
 documents = []
 
 model_documents = {}
-model_doc_types = {}
 app_documents = {}
 
 
@@ -26,7 +25,5 @@ def register(doc_class, app_label=None):
             model_class = doc_class.queryset().model
         # It's possible to register more than one document type for a model, so keep a list.
         model_documents.setdefault(model_class, []).append(doc_class)
-        # For doing queries across multiple document types, we'll need a mapping from doc_type back to model_class.
-        model_doc_types[doc_class._doc_type.name] = model_class
     if app_label:
         app_documents.setdefault(app_label, []).append(doc_class)
